aboutsummaryrefslogtreecommitdiffstats
path: root/core/test/interface.go
diff options
context:
space:
mode:
Diffstat (limited to 'core/test/interface.go')
-rw-r--r--core/test/interface.go8
1 files changed, 4 insertions, 4 deletions
diff --git a/core/test/interface.go b/core/test/interface.go
index dcecee8..1388dc1 100644
--- a/core/test/interface.go
+++ b/core/test/interface.go
@@ -18,15 +18,15 @@
package test
import (
- "github.com/dexon-foundation/dexon-consensus/core/blockdb"
"github.com/dexon-foundation/dexon-consensus/core/crypto"
+ "github.com/dexon-foundation/dexon-consensus/core/db"
"github.com/dexon-foundation/dexon-consensus/core/types"
)
// Revealer defines the interface to reveal a group
// of pre-generated blocks.
-type Revealer interface {
- blockdb.BlockIterator
+type BlockRevealer interface {
+ db.BlockIterator
// Reset the revealing.
Reset()
@@ -18,15 +18,15 @@
"github.com/dexon-foundation/dexon-consensus/core/types"
)
-// Revealer defines the interface to reveal a group
+// BlockRevealer defines the interface to reveal a group
// of pre-generated blocks.